@@ -25,14 +25,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__version__ = '1.6.2'
+__version__ = '1.7.0'
 
 import asyncio
 from sys import platform, version_info
 
 from .client import Client, run_multiple, start_multiple, close_multiple
 from .auth import (EmailAndPasswordAuth, ExchangeCodeAuth, DeviceAuth,
-                   AdvancedAuth)
+                   RefreshTokenAuth, AdvancedAuth)
 from .friend import Friend, PendingFriend
 from .message import FriendMessage, PartyMessage
 from .party import (PartyMember, ClientPartyMember, Party, ClientParty,
